'Tutorial 1: Total energy for metallic Li (single point)'

# Import Siman libraries and read configuration files
from siman.header import _update_configuration, db #DFT manager https://github.com/dimonaks/siman
from siman.calc_manage import smart_structure_read, add, res
from siman.set_functions import read_vasp_sets
from siman.database import read_database

_update_configuration('simanrc.py') # read main configuration file
read_database(); # read saved calculations and sets from database files calc.gdbm and only_calc.gdbm



#Read structure file POSCAR and convert to xyz and cif formats:

if 0: #change into 1 if you want to perform this code

    st = smart_structure_read('Li2.POSCAR') #read POSCAR file, which you can find in your home directiory
    st.printme() # show structure object

    print('\nThe space group is',st.sg(silent = 1),'\n');
    st.write_xyz(); # xyz format
    st.write_cif(); # cif format


#Check all predefined INCAR files (sets of input parameters)
if 0:
    import project_sets # should be after read_database
    varset = read_vasp_sets(project_sets.user_vasp_sets, override_global = 0) #read user sets from file project_sets.py

    print('Available sets are ', varset.keys(), '\n') # varset is a dictionary with created sets of VASP parameters (a la INCAR files)

    print('VASP parameters for *sp* set are:\n')
    varset['sp'].printme() #

#Submit job to cluster and read results of calculation
if 0:
    add('Li', 'sp', 1, input_st = st, it_folder = 'Li/', run = 1); #create all files and submit job on cluster
    # res('Li', 'sp', 1); #read resuts of calculation
    #now you can find output files of given calculation in 'your_home_folder/Li/Li.static_opt/'


# The results of calculation were written into database, you can read it easily by a key,
# which consists of three elements: chosen by user name, set name, and integer number of structure
if 0:

    Li = db['Li.sp.1'] # db[name.set.number]

    # For example you can print a total energy of this structure
    print('The total energy is ', Li.e0, 'eV\n')

    # To check the crystal structure use
    Li.end.printme()
    print('\nVASP parameters used for Li calculation are:\n')
    # To check calculation parameters use
    Li.set.printme() #show the VASP parameters of given calculation object

    # To see all available properties check siman.core.calculation source file